# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .data_entity_summary import DataEntitySummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataEntitySummaryFromDataStore(DataEntitySummary):
    """
    The view entity data entity details.
    """

    #: A constant which can be used with the entity_type property of a DataEntitySummaryFromDataStore.
    #: This constant has a value of "TABLE"
    ENTITY_TYPE_TABLE = "TABLE"

    #: A constant which can be used with the entity_type property of a DataEntitySummaryFromDataStore.
    #: This constant has a value of "VIEW"
    ENTITY_TYPE_VIEW = "VIEW"

    #: A constant which can be used with the entity_type property of a DataEntitySummaryFromDataStore.
    #: This constant has a value of "FILE"
    ENTITY_TYPE_FILE = "FILE"

    #: A constant which can be used with the entity_type property of a DataEntitySummaryFromDataStore.
    #: This constant has a value of "QUEUE"
    ENTITY_TYPE_QUEUE = "QUEUE"

    #: A constant which can be used with the entity_type property of a DataEntitySummaryFromDataStore.
    #: This constant has a value of "STREAM"
    ENTITY_TYPE_STREAM = "STREAM"

    #: A constant which can be used with the entity_type property of a DataEntitySummaryFromDataStore.
    #: This constant has a value of "OTHER"
    ENTITY_TYPE_OTHER = "OTHER"

    #: A constant which can be used with the entity_type property of a DataEntitySummaryFromDataStore.
    #: This constant has a value of "DATA_STORE"
    ENTITY_TYPE_DATA_STORE = "DATA_STORE"

    def __init__(self, **kwargs):
        """
        Initializes a new DataEntitySummaryFromDataStore object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.DataEntitySummaryFromDataStore.model_type` attribute
        of this class is ``DATA_STORE_ENTITY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DataEntitySummaryFromDataStore.
            Allowed values for this property are: "VIEW_ENTITY", "TABLE_ENTITY", "FILE_ENTITY", "DATA_STORE_ENTITY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param metadata:
            The value to assign to the metadata property of this DataEntitySummaryFromDataStore.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key:
            The value to assign to the key property of this DataEntitySummaryFromDataStore.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this DataEntitySummaryFromDataStore.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this DataEntitySummaryFromDataStore.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this DataEntitySummaryFromDataStore.
        :type name: str

        :param description:
            The value to assign to the description property of this DataEntitySummaryFromDataStore.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this DataEntitySummaryFromDataStore.
        :type object_version: int

        :param external_key:
            The value to assign to the external_key property of this DataEntitySummaryFromDataStore.
        :type external_key: str

        :param shape:
            The value to assign to the shape property of this DataEntitySummaryFromDataStore.
        :type shape: oci.data_integration.models.Shape

        :param shape_id:
            The value to assign to the shape_id property of this DataEntitySummaryFromDataStore.
        :type shape_id: str

        :param types:
            The value to assign to the types property of this DataEntitySummaryFromDataStore.
        :type types: oci.data_integration.models.TypeLibrary

        :param entity_type:
            The value to assign to the entity_type property of this DataEntitySummaryFromDataStore.
            Allowed values for this property are: "TABLE", "VIEW", "FILE", "QUEUE", "STREAM", "OTHER", "DATA_STORE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_type: str

        :param other_type_label:
            The value to assign to the other_type_label property of this DataEntitySummaryFromDataStore.
        :type other_type_label: str

        :param unique_keys:
            The value to assign to the unique_keys property of this DataEntitySummaryFromDataStore.
        :type unique_keys: list[oci.data_integration.models.UniqueKey]

        :param foreign_keys:
            The value to assign to the foreign_keys property of this DataEntitySummaryFromDataStore.
        :type foreign_keys: list[oci.data_integration.models.ForeignKey]

        :param resource_name:
            The value to assign to the resource_name property of this DataEntitySummaryFromDataStore.
        :type resource_name: str

        :param object_status:
            The value to assign to the object_status property of this DataEntitySummaryFromDataStore.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this DataEntitySummaryFromDataStore.
        :type identifier: str

        :param filters:
            The value to assign to the filters property of this DataEntitySummaryFromDataStore.
        :type filters: str

        :param is_effective_date_disabled:
            The value to assign to the is_effective_date_disabled property of this DataEntitySummaryFromDataStore.
        :type is_effective_date_disabled: bool

        :param is_flex_data_store:
            The value to assign to the is_flex_data_store property of this DataEntitySummaryFromDataStore.
        :type is_flex_data_store: bool

        :param is_silent_error:
            The value to assign to the is_silent_error property of this DataEntitySummaryFromDataStore.
        :type is_silent_error: bool

        :param supports_incremental:
            The value to assign to the supports_incremental property of this DataEntitySummaryFromDataStore.
        :type supports_incremental: bool

        """
        self.swagger_types = {
            'model_type': 'str',
            'metadata': 'ObjectMetadata',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'external_key': 'str',
            'shape': 'Shape',
            'shape_id': 'str',
            'types': 'TypeLibrary',
            'entity_type': 'str',
            'other_type_label': 'str',
            'unique_keys': 'list[UniqueKey]',
            'foreign_keys': 'list[ForeignKey]',
            'resource_name': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'filters': 'str',
            'is_effective_date_disabled': 'bool',
            'is_flex_data_store': 'bool',
            'is_silent_error': 'bool',
            'supports_incremental': 'bool'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'metadata': 'metadata',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'external_key': 'externalKey',
            'shape': 'shape',
            'shape_id': 'shapeId',
            'types': 'types',
            'entity_type': 'entityType',
            'other_type_label': 'otherTypeLabel',
            'unique_keys': 'uniqueKeys',
            'foreign_keys': 'foreignKeys',
            'resource_name': 'resourceName',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'filters': 'filters',
            'is_effective_date_disabled': 'isEffectiveDateDisabled',
            'is_flex_data_store': 'isFlexDataStore',
            'is_silent_error': 'isSilentError',
            'supports_incremental': 'supportsIncremental'
        }

        self._model_type = None
        self._metadata = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._external_key = None
        self._shape = None
        self._shape_id = None
        self._types = None
        self._entity_type = None
        self._other_type_label = None
        self._unique_keys = None
        self._foreign_keys = None
        self._resource_name = None
        self._object_status = None
        self._identifier = None
        self._filters = None
        self._is_effective_date_disabled = None
        self._is_flex_data_store = None
        self._is_silent_error = None
        self._supports_incremental = None
        self._model_type = 'DATA_STORE_ENTITY'

    @property
    def key(self):
        """
        Gets the key of this DataEntitySummaryFromDataStore.
        The object key.


        :return: The key of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this DataEntitySummaryFromDataStore.
        The object key.


        :param key: The key of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this DataEntitySummaryFromDataStore.
        The object's model version.


        :return: The model_version of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this DataEntitySummaryFromDataStore.
        The object's model version.


        :param model_version: The model_version of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this DataEntitySummaryFromDataStore.

        :return: The parent_ref of this DataEntitySummaryFromDataStore.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this DataEntitySummaryFromDataStore.

        :param parent_ref: The parent_ref of this DataEntitySummaryFromDataStore.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this DataEntitySummaryFromDataStore.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DataEntitySummaryFromDataStore.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this DataEntitySummaryFromDataStore.
        Detailed description for the object.


        :return: The description of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DataEntitySummaryFromDataStore.
        Detailed description for the object.


        :param description: The description of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this DataEntitySummaryFromDataStore.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this DataEntitySummaryFromDataStore.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this DataEntitySummaryFromDataStore.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this DataEntitySummaryFromDataStore.
        :type: int
        """
        self._object_version = object_version

    @property
    def external_key(self):
        """
        Gets the external_key of this DataEntitySummaryFromDataStore.
        The external key for the object


        :return: The external_key of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this DataEntitySummaryFromDataStore.
        The external key for the object


        :param external_key: The external_key of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._external_key = external_key

    @property
    def shape(self):
        """
        Gets the shape of this DataEntitySummaryFromDataStore.

        :return: The shape of this DataEntitySummaryFromDataStore.
        :rtype: oci.data_integration.models.Shape
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this DataEntitySummaryFromDataStore.

        :param shape: The shape of this DataEntitySummaryFromDataStore.
        :type: oci.data_integration.models.Shape
        """
        self._shape = shape

    @property
    def shape_id(self):
        """
        Gets the shape_id of this DataEntitySummaryFromDataStore.
        The shape ID.


        :return: The shape_id of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._shape_id

    @shape_id.setter
    def shape_id(self, shape_id):
        """
        Sets the shape_id of this DataEntitySummaryFromDataStore.
        The shape ID.


        :param shape_id: The shape_id of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._shape_id = shape_id

    @property
    def types(self):
        """
        Gets the types of this DataEntitySummaryFromDataStore.

        :return: The types of this DataEntitySummaryFromDataStore.
        :rtype: oci.data_integration.models.TypeLibrary
        """
        return self._types

    @types.setter
    def types(self, types):
        """
        Sets the types of this DataEntitySummaryFromDataStore.

        :param types: The types of this DataEntitySummaryFromDataStore.
        :type: oci.data_integration.models.TypeLibrary
        """
        self._types = types

    @property
    def entity_type(self):
        """
        Gets the entity_type of this DataEntitySummaryFromDataStore.
        The entity type.

        Allowed values for this property are: "TABLE", "VIEW", "FILE", "QUEUE", "STREAM", "OTHER", "DATA_STORE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_type of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this DataEntitySummaryFromDataStore.
        The entity type.


        :param entity_type: The entity_type of this DataEntitySummaryFromDataStore.
        :type: str
        """
        allowed_values = ["TABLE", "VIEW", "FILE", "QUEUE", "STREAM", "OTHER", "DATA_STORE"]
        if not value_allowed_none_or_none_sentinel(entity_type, allowed_values):
            entity_type = 'UNKNOWN_ENUM_VALUE'
        self._entity_type = entity_type

    @property
    def other_type_label(self):
        """
        Gets the other_type_label of this DataEntitySummaryFromDataStore.
        Specifies other type label.


        :return: The other_type_label of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._other_type_label

    @other_type_label.setter
    def other_type_label(self, other_type_label):
        """
        Sets the other_type_label of this DataEntitySummaryFromDataStore.
        Specifies other type label.


        :param other_type_label: The other_type_label of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._other_type_label = other_type_label

    @property
    def unique_keys(self):
        """
        Gets the unique_keys of this DataEntitySummaryFromDataStore.
        An array of unique keys.


        :return: The unique_keys of this DataEntitySummaryFromDataStore.
        :rtype: list[oci.data_integration.models.UniqueKey]
        """
        return self._unique_keys

    @unique_keys.setter
    def unique_keys(self, unique_keys):
        """
        Sets the unique_keys of this DataEntitySummaryFromDataStore.
        An array of unique keys.


        :param unique_keys: The unique_keys of this DataEntitySummaryFromDataStore.
        :type: list[oci.data_integration.models.UniqueKey]
        """
        self._unique_keys = unique_keys

    @property
    def foreign_keys(self):
        """
        Gets the foreign_keys of this DataEntitySummaryFromDataStore.
        An array of foreign keys.


        :return: The foreign_keys of this DataEntitySummaryFromDataStore.
        :rtype: list[oci.data_integration.models.ForeignKey]
        """
        return self._foreign_keys

    @foreign_keys.setter
    def foreign_keys(self, foreign_keys):
        """
        Sets the foreign_keys of this DataEntitySummaryFromDataStore.
        An array of foreign keys.


        :param foreign_keys: The foreign_keys of this DataEntitySummaryFromDataStore.
        :type: list[oci.data_integration.models.ForeignKey]
        """
        self._foreign_keys = foreign_keys

    @property
    def resource_name(self):
        """
        Gets the resource_name of this DataEntitySummaryFromDataStore.
        The resource name.


        :return: The resource_name of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this DataEntitySummaryFromDataStore.
        The resource name.


        :param resource_name: The resource_name of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def object_status(self):
        """
        Gets the object_status of this DataEntitySummaryFromDataStore.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this DataEntitySummaryFromDataStore.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this DataEntitySummaryFromDataStore.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this DataEntitySummaryFromDataStore.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this DataEntitySummaryFromDataStore.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this DataEntitySummaryFromDataStore.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._identifier = identifier

    @property
    def filters(self):
        """
        Gets the filters of this DataEntitySummaryFromDataStore.
        Query filter for the extract. It can be Null.


        :return: The filters of this DataEntitySummaryFromDataStore.
        :rtype: str
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this DataEntitySummaryFromDataStore.
        Query filter for the extract. It can be Null.


        :param filters: The filters of this DataEntitySummaryFromDataStore.
        :type: str
        """
        self._filters = filters

    @property
    def is_effective_date_disabled(self):
        """
        Gets the is_effective_date_disabled of this DataEntitySummaryFromDataStore.
        It shows whether or not effective date is disabled


        :return: The is_effective_date_disabled of this DataEntitySummaryFromDataStore.
        :rtype: bool
        """
        return self._is_effective_date_disabled

    @is_effective_date_disabled.setter
    def is_effective_date_disabled(self, is_effective_date_disabled):
        """
        Sets the is_effective_date_disabled of this DataEntitySummaryFromDataStore.
        It shows whether or not effective date is disabled


        :param is_effective_date_disabled: The is_effective_date_disabled of this DataEntitySummaryFromDataStore.
        :type: bool
        """
        self._is_effective_date_disabled = is_effective_date_disabled

    @property
    def is_flex_data_store(self):
        """
        Gets the is_flex_data_store of this DataEntitySummaryFromDataStore.
        Is Flex data store. Metadata csv will be generated for flex data store


        :return: The is_flex_data_store of this DataEntitySummaryFromDataStore.
        :rtype: bool
        """
        return self._is_flex_data_store

    @is_flex_data_store.setter
    def is_flex_data_store(self, is_flex_data_store):
        """
        Sets the is_flex_data_store of this DataEntitySummaryFromDataStore.
        Is Flex data store. Metadata csv will be generated for flex data store


        :param is_flex_data_store: The is_flex_data_store of this DataEntitySummaryFromDataStore.
        :type: bool
        """
        self._is_flex_data_store = is_flex_data_store

    @property
    def is_silent_error(self):
        """
        Gets the is_silent_error of this DataEntitySummaryFromDataStore.
        Should the VO failure fail the whole batch?


        :return: The is_silent_error of this DataEntitySummaryFromDataStore.
        :rtype: bool
        """
        return self._is_silent_error

    @is_silent_error.setter
    def is_silent_error(self, is_silent_error):
        """
        Sets the is_silent_error of this DataEntitySummaryFromDataStore.
        Should the VO failure fail the whole batch?


        :param is_silent_error: The is_silent_error of this DataEntitySummaryFromDataStore.
        :type: bool
        """
        self._is_silent_error = is_silent_error

    @property
    def supports_incremental(self):
        """
        Gets the supports_incremental of this DataEntitySummaryFromDataStore.
        It shows whether the datastore supports Incremental Extract or not.


        :return: The supports_incremental of this DataEntitySummaryFromDataStore.
        :rtype: bool
        """
        return self._supports_incremental

    @supports_incremental.setter
    def supports_incremental(self, supports_incremental):
        """
        Sets the supports_incremental of this DataEntitySummaryFromDataStore.
        It shows whether the datastore supports Incremental Extract or not.


        :param supports_incremental: The supports_incremental of this DataEntitySummaryFromDataStore.
        :type: bool
        """
        self._supports_incremental = supports_incremental

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DetachInstancePoolInstanceDetails(object):
    """
    An instance that is to be detached from an instance pool.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DetachInstancePoolInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_id:
            The value to assign to the instance_id property of this DetachInstancePoolInstanceDetails.
        :type instance_id: str

        :param is_decrement_size:
            The value to assign to the is_decrement_size property of this DetachInstancePoolInstanceDetails.
        :type is_decrement_size: bool

        :param is_auto_terminate:
            The value to assign to the is_auto_terminate property of this DetachInstancePoolInstanceDetails.
        :type is_auto_terminate: bool

        """
        self.swagger_types = {
            'instance_id': 'str',
            'is_decrement_size': 'bool',
            'is_auto_terminate': 'bool'
        }

        self.attribute_map = {
            'instance_id': 'instanceId',
            'is_decrement_size': 'isDecrementSize',
            'is_auto_terminate': 'isAutoTerminate'
        }

        self._instance_id = None
        self._is_decrement_size = None
        self._is_auto_terminate = None

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this DetachInstancePoolInstanceDetails.
        The `OCID`__ of the instance.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The instance_id of this DetachInstancePoolInstanceDetails.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this DetachInstancePoolInstanceDetails.
        The `OCID`__ of the instance.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param instance_id: The instance_id of this DetachInstancePoolInstanceDetails.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def is_decrement_size(self):
        """
        Gets the is_decrement_size of this DetachInstancePoolInstanceDetails.
        Whether to decrease the size of the instance pool when the instance is detached. If `true`, the
        pool size is decreased. If `false`, the pool will provision a new, replacement instance
        using the pool's instance configuration as a template. Default is `true`.


        :return: The is_decrement_size of this DetachInstancePoolInstanceDetails.
        :rtype: bool
        """
        return self._is_decrement_size

    @is_decrement_size.setter
    def is_decrement_size(self, is_decrement_size):
        """
        Sets the is_decrement_size of this DetachInstancePoolInstanceDetails.
        Whether to decrease the size of the instance pool when the instance is detached. If `true`, the
        pool size is decreased. If `false`, the pool will provision a new, replacement instance
        using the pool's instance configuration as a template. Default is `true`.


        :param is_decrement_size: The is_decrement_size of this DetachInstancePoolInstanceDetails.
        :type: bool
        """
        self._is_decrement_size = is_decrement_size

    @property
    def is_auto_terminate(self):
        """
        Gets the is_auto_terminate of this DetachInstancePoolInstanceDetails.
        Whether to permanently terminate (delete) the instance and its attached boot volume
        when detaching it from the instance pool. Default is `false`.


        :return: The is_auto_terminate of this DetachInstancePoolInstanceDetails.
        :rtype: bool
        """
        return self._is_auto_terminate

    @is_auto_terminate.setter
    def is_auto_terminate(self, is_auto_terminate):
        """
        Sets the is_auto_terminate of this DetachInstancePoolInstanceDetails.
        Whether to permanently terminate (delete) the instance and its attached boot volume
        when detaching it from the instance pool. Default is `false`.


        :param is_auto_terminate: The is_auto_terminate of this DetachInstancePoolInstanceDetails.
        :type: bool
        """
        self._is_auto_terminate = is_auto_terminate

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .push_down_operation import PushDownOperation
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Query(PushDownOperation):
    """
    A query object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Query object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.Query.model_type` attribute
        of this class is ``QUERY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this Query.
            Allowed values for this property are: "FILTER", "JOIN", "SELECT", "SORT", "QUERY"
        :type model_type: str

        :param query:
            The value to assign to the query property of this Query.
        :type query: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'query': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'query': 'query'
        }

        self._model_type = None
        self._query = None
        self._model_type = 'QUERY'

    @property
    def query(self):
        """
        Gets the query of this Query.
        A query string.


        :return: The query of this Query.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this Query.
        A query string.


        :param query: The query of this Query.
        :type: str
        """
        self._query = query

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdatePatternDetails(object):
    """
    Properties used in pattern update operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdatePatternDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdatePatternDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdatePatternDetails.
        :type description: str

        :param expression:
            The value to assign to the expression property of this UpdatePatternDetails.
        :type expression: str

        :param check_file_path_list:
            The value to assign to the check_file_path_list property of this UpdatePatternDetails.
        :type check_file_path_list: list[str]

        :param is_enable_check_failure_limit:
            The value to assign to the is_enable_check_failure_limit property of this UpdatePatternDetails.
        :type is_enable_check_failure_limit: bool

        :param check_failure_limit:
            The value to assign to the check_failure_limit property of this UpdatePatternDetails.
        :type check_failure_limit: int

        :param properties:
            The value to assign to the properties property of this UpdatePatternDetails.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'expression': 'str',
            'check_file_path_list': 'list[str]',
            'is_enable_check_failure_limit': 'bool',
            'check_failure_limit': 'int',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'expression': 'expression',
            'check_file_path_list': 'checkFilePathList',
            'is_enable_check_failure_limit': 'isEnableCheckFailureLimit',
            'check_failure_limit': 'checkFailureLimit',
            'properties': 'properties'
        }

        self._display_name = None
        self._description = None
        self._expression = None
        self._check_file_path_list = None
        self._is_enable_check_failure_limit = None
        self._check_failure_limit = None
        self._properties = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdatePatternDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdatePatternDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdatePatternDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdatePatternDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdatePatternDetails.
        Detailed description of the Pattern.


        :return: The description of this UpdatePatternDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdatePatternDetails.
        Detailed description of the Pattern.


        :param description: The description of this UpdatePatternDetails.
        :type: str
        """
        self._description = description

    @property
    def expression(self):
        """
        Gets the expression of this UpdatePatternDetails.
        The expression used in the pattern that may include qualifiers. Refer to the user documentation for details of the format and examples.


        :return: The expression of this UpdatePatternDetails.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """
        Sets the expression of this UpdatePatternDetails.
        The expression used in the pattern that may include qualifiers. Refer to the user documentation for details of the format and examples.


        :param expression: The expression of this UpdatePatternDetails.
        :type: str
        """
        self._expression = expression

    @property
    def check_file_path_list(self):
        """
        Gets the check_file_path_list of this UpdatePatternDetails.
        List of file paths against which the expression can be tried, as a check. This documents, for reference
        purposes, some example objects a pattern is meant to work with. If isEnableCheckFailureLimit is set to true,
        this will be run as a validation during the request, such that if the check fails the request fails. If
        isEnableCheckFailureLimit instead is set to (the default) false, a pattern will still be created or updated even
        if the check fails, with a lifecycleState of FAILED.


        :return: The check_file_path_list of this UpdatePatternDetails.
        :rtype: list[str]
        """
        return self._check_file_path_list

    @check_file_path_list.setter
    def check_file_path_list(self, check_file_path_list):
        """
        Sets the check_file_path_list of this UpdatePatternDetails.
        List of file paths against which the expression can be tried, as a check. This documents, for reference
        purposes, some example objects a pattern is meant to work with. If isEnableCheckFailureLimit is set to true,
        this will be run as a validation during the request, such that if the check fails the request fails. If
        isEnableCheckFailureLimit instead is set to (the default) false, a pattern will still be created or updated even
        if the check fails, with a lifecycleState of FAILED.


        :param check_file_path_list: The check_file_path_list of this UpdatePatternDetails.
        :type: list[str]
        """
        self._check_file_path_list = check_file_path_list

    @property
    def is_enable_check_failure_limit(self):
        """
        Gets the is_enable_check_failure_limit of this UpdatePatternDetails.
        Indicates whether the expression check, against the checkFilePathList, will fail the request if the count of
        UNMATCHED files is above the checkFailureLimit.


        :return: The is_enable_check_failure_limit of this UpdatePatternDetails.
        :rtype: bool
        """
        return self._is_enable_check_failure_limit

    @is_enable_check_failure_limit.setter
    def is_enable_check_failure_limit(self, is_enable_check_failure_limit):
        """
        Sets the is_enable_check_failure_limit of this UpdatePatternDetails.
        Indicates whether the expression check, against the checkFilePathList, will fail the request if the count of
        UNMATCHED files is above the checkFailureLimit.


        :param is_enable_check_failure_limit: The is_enable_check_failure_limit of this UpdatePatternDetails.
        :type: bool
        """
        self._is_enable_check_failure_limit = is_enable_check_failure_limit

    @property
    def check_failure_limit(self):
        """
        Gets the check_failure_limit of this UpdatePatternDetails.
        The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if
        checkFilePathList is provided - but if isEnableCheckFailureLimit is set to true it is required.


        :return: The check_failure_limit of this UpdatePatternDetails.
        :rtype: int
        """
        return self._check_failure_limit

    @check_failure_limit.setter
    def check_failure_limit(self, check_failure_limit):
        """
        Sets the check_failure_limit of this UpdatePatternDetails.
        The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if
        checkFilePathList is provided - but if isEnableCheckFailureLimit is set to true it is required.


        :param check_failure_limit: The check_failure_limit of this UpdatePatternDetails.
        :type: int
        """
        self._check_failure_limit = check_failure_limit

    @property
    def properties(self):
        """
        Gets the properties of this UpdatePatternDetails.
        A map of maps that contains the properties which are specific to the pattern type. Each pattern type
        definition defines it's set of required and optional properties.
        Example: `{\"properties\": { \"default\": { \"tbd\"}}}`


        :return: The properties of this UpdatePatternDetails.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdatePatternDetails.
        A map of maps that contains the properties which are specific to the pattern type. Each pattern type
        definition defines it's set of required and optional properties.
        Example: `{\"properties\": { \"default\": { \"tbd\"}}}`


        :param properties: The properties of this UpdatePatternDetails.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import rover_type_mapping
missing = Sentinel("Missing")


class RoverEntitlementClient(object):
    """
    A description of the RoverCloudService API.
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20201210',
            'service_endpoint_template': 'https://rover.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        self.base_client = BaseClient("rover_entitlement", config, signer, rover_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')

    def change_rover_entitlement_compartment(self, rover_entitlement_id, change_rover_entitlement_compartment_details, **kwargs):
        """
        Moves an entitlement into a different compartment.


        :param str rover_entitlement_id: (required)
            ID of the rover node or cluster entitlement

        :param oci.rover.models.ChangeRoverEntitlementCompartmentDetails change_rover_entitlement_compartment_details: (required)
            CompartmentId of the destination compartment

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/rover/change_rover_entitlement_compartment.py.html>`__ to see an example of how to use change_rover_entitlement_compartment API.
        """
        resource_path = "/roverEntitlements/{roverEntitlementId}/actions/changeCompartment"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id",
            "opc_retry_token"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "change_rover_entitlement_compartment got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "roverEntitlementId": rover_entitlement_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing),
            "opc-retry-token": kwargs.get("opc_retry_token", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_rover_entitlement_compartment_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_rover_entitlement_compartment_details)

    def create_rover_entitlement(self, create_rover_entitlement_details, **kwargs):
        """
        Create the Entitlement to use a Rover Device. It requires some offline process of review and signatures before request is granted.


        :param oci.rover.models.CreateRoverEntitlementDetails create_rover_entitlement_details: (required)
            Creates a Rover Device Entitlement

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.rover.models.RoverEntitlement`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/rover/create_rover_entitlement.py.html>`__ to see an example of how to use create_rover_entitlement API.
        """
        resource_path = "/roverEntitlements"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_rover_entitlement got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_rover_entitlement_details,
                response_type="RoverEntitlement")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_rover_entitlement_details,
                response_type="RoverEntitlement")

    def delete_rover_entitlement(self, rover_entitlement_id, **kwargs):
        """
        Deletes a rover entitlement


        :param str rover_entitlement_id: (required)
            ID of the rover node or cluster entitlement

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/rover/delete_rover_entitlement.py.html>`__ to see an example of how to use delete_rover_entitlement API.
        """
        resource_path = "/roverEntitlements/{roverEntitlementId}"
        method = "DELETE"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id",
            "if_match"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_rover_entitlement got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "roverEntitlementId": rover_entitlement_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing),
            "if-match": kwargs.get("if_match", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def get_rover_entitlement(self, rover_entitlement_id, compartment_id, **kwargs):
        """
        Describes the Rover Device Entitlement in detail


        :param str rover_entitlement_id: (required)
            ID of the rover node or cluster entitlement

        :param str compartment_id: (required)
            The OCID of the compartment in which to list resources.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.rover.models.RoverEntitlement`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/rover/get_rover_entitlement.py.html>`__ to see an example of how to use get_rover_entitlement API.
        """
        resource_path = "/roverEntitlements/{roverEntitlementId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_rover_entitlement got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "roverEntitlementId": rover_entitlement_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        query_params = {
            "compartmentId": compartment_id
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="RoverEntitlement")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="RoverEntitlement")

    def list_rover_entitlements(self, compartment_id, **kwargs):
        """
        Returns a list of RoverEntitlements.


        :param str compartment_id: (required)
            The OCID of the compartment in which to list resources.

        :param str id: (optional)
            filtering by Rover Device Entitlement id

        :param str display_name: (optional)
            A filter to return only resources that match the entire display name given.

        :param str lifecycle_state: (optional)
            A filter to return only resources their lifecycleState matches the given lifecycleState.

            Allowed values are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"

        :param int limit: (optional)
            The maximum number of items to return.

        :param str page: (optional)
            The page token representing the page at which to start retrieving results. This is usually retrieved from a previous list call.

        :param str sort_order: (optional)
            The sort order to use, either 'asc' or 'desc'.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            The field to sort by. Only one sort order may be provided. Default order for timeCreated is descending. Default order for displayName is ascending. If no value is specified timeCreated is default.

            Allowed values are: "timeCreated", "displayName"

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.rover.models.RoverEntitlementCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/rover/list_rover_entitlements.py.html>`__ to see an example of how to use list_rover_entitlements API.
        """
        resource_path = "/roverEntitlements"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "id",
            "display_name",
            "lifecycle_state",
            "limit",
            "page",
            "sort_order",
            "sort_by",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_rover_entitlements got unknown kwargs: {!r}".format(extra_kwargs))

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        query_params = {
            "id": kwargs.get("id", missing),
            "compartmentId": compartment_id,
            "displayName": kwargs.get("display_name", missing),
            "lifecycleState": kwargs.get("lifecycle_state", missing),
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="RoverEntitlementCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="RoverEntitlementCollection")

    def update_rover_entitlement(self, rover_entitlement_id, update_rover_entitlement_details, **kwargs):
        """
        Updates the RoverEntitlement


        :param str rover_entitlement_id: (required)
            ID of the rover node or cluster entitlement

        :param oci.rover.models.UpdateRoverEntitlementDetails update_rover_entitlement_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.rover.models.RoverEntitlement`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/rover/update_rover_entitlement.py.html>`__ to see an example of how to use update_rover_entitlement API.
        """
        resource_path = "/roverEntitlements/{roverEntitlementId}"
        method = "PUT"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_rover_entitlement got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "roverEntitlementId": rover_entitlement_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_rover_entitlement_details,
                response_type="RoverEntitlement")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_rover_entitlement_details,
                response_type="RoverEntitlement")



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Erratum(object):
    """
    Details about the erratum.
    """

    #: A constant which can be used with the advisory_type property of a Erratum.
    #: This constant has a value of "SECURITY"
    ADVISORY_TYPE_SECURITY = "SECURITY"

    #: A constant which can be used with the advisory_type property of a Erratum.
    #: This constant has a value of "BUG"
    ADVISORY_TYPE_BUG = "BUG"

    #: A constant which can be used with the advisory_type property of a Erratum.
    #: This constant has a value of "ENHANCEMENT"
    ADVISORY_TYPE_ENHANCEMENT = "ENHANCEMENT"

    #: A constant which can be used with the advisory_type property of a Erratum.
    #: This constant has a value of "OTHER"
    ADVISORY_TYPE_OTHER = "OTHER"

    def __init__(self, **kwargs):
        """
        Initializes a new Erratum object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Erratum.
        :type name: str

        :param id:
            The value to assign to the id property of this Erratum.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Erratum.
        :type compartment_id: str

        :param synopsis:
            The value to assign to the synopsis property of this Erratum.
        :type synopsis: str

        :param issued:
            The value to assign to the issued property of this Erratum.
        :type issued: str

        :param description:
            The value to assign to the description property of this Erratum.
        :type description: str

        :param updated:
            The value to assign to the updated property of this Erratum.
        :type updated: str

        :param advisory_type:
            The value to assign to the advisory_type property of this Erratum.
            Allowed values for this property are: "SECURITY", "BUG", "ENHANCEMENT", "OTHER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type advisory_type: str

        :param _from:
            The value to assign to the _from property of this Erratum.
        :type _from: str

        :param solution:
            The value to assign to the solution property of this Erratum.
        :type solution: str

        :param references:
            The value to assign to the references property of this Erratum.
        :type references: str

        :param affected_instances:
            The value to assign to the affected_instances property of this Erratum.
        :type affected_instances: list[oci.os_management.models.Id]

        :param related_cves:
            The value to assign to the related_cves property of this Erratum.
        :type related_cves: list[str]

        :param software_sources:
            The value to assign to the software_sources property of this Erratum.
        :type software_sources: list[oci.os_management.models.Id]

        :param packages:
            The value to assign to the packages property of this Erratum.
        :type packages: list[oci.os_management.models.SoftwarePackageSummary]

        """
        self.swagger_types = {
            'name': 'str',
            'id': 'str',
            'compartment_id': 'str',
            'synopsis': 'str',
            'issued': 'str',
            'description': 'str',
            'updated': 'str',
            'advisory_type': 'str',
            '_from': 'str',
            'solution': 'str',
            'references': 'str',
            'affected_instances': 'list[Id]',
            'related_cves': 'list[str]',
            'software_sources': 'list[Id]',
            'packages': 'list[SoftwarePackageSummary]'
        }

        self.attribute_map = {
            'name': 'name',
            'id': 'id',
            'compartment_id': 'compartmentId',
            'synopsis': 'synopsis',
            'issued': 'issued',
            'description': 'description',
            'updated': 'updated',
            'advisory_type': 'advisoryType',
            '_from': 'from',
            'solution': 'solution',
            'references': 'references',
            'affected_instances': 'affectedInstances',
            'related_cves': 'relatedCves',
            'software_sources': 'softwareSources',
            'packages': 'packages'
        }

        self._name = None
        self._id = None
        self._compartment_id = None
        self._synopsis = None
        self._issued = None
        self._description = None
        self._updated = None
        self._advisory_type = None
        self.__from = None
        self._solution = None
        self._references = None
        self._affected_instances = None
        self._related_cves = None
        self._software_sources = None
        self._packages = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Erratum.
        Advisory name


        :return: The name of this Erratum.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Erratum.
        Advisory name


        :param name: The name of this Erratum.
        :type: str
        """
        self._name = name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Erratum.
        OCID for the Erratum.


        :return: The id of this Erratum.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Erratum.
        OCID for the Erratum.


        :param id: The id of this Erratum.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Erratum.
        OCID for the Compartment.


        :return: The compartment_id of this Erratum.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Erratum.
        OCID for the Compartment.


        :param compartment_id: The compartment_id of this Erratum.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def synopsis(self):
        """
        Gets the synopsis of this Erratum.
        Summary description of the erratum.


        :return: The synopsis of this Erratum.
        :rtype: str
        """
        return self._synopsis

    @synopsis.setter
    def synopsis(self, synopsis):
        """
        Sets the synopsis of this Erratum.
        Summary description of the erratum.


        :param synopsis: The synopsis of this Erratum.
        :type: str
        """
        self._synopsis = synopsis

    @property
    def issued(self):
        """
        Gets the issued of this Erratum.
        date the erratum was issued


        :return: The issued of this Erratum.
        :rtype: str
        """
        return self._issued

    @issued.setter
    def issued(self, issued):
        """
        Sets the issued of this Erratum.
        date the erratum was issued


        :param issued: The issued of this Erratum.
        :type: str
        """
        self._issued = issued

    @property
    def description(self):
        """
        Gets the description of this Erratum.
        Details describing the erratum.


        :return: The description of this Erratum.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Erratum.
        Details describing the erratum.


        :param description: The description of this Erratum.
        :type: str
        """
        self._description = description

    @property
    def updated(self):
        """
        Gets the updated of this Erratum.
        most recent date the erratum was updated


        :return: The updated of this Erratum.
        :rtype: str
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """
        Sets the updated of this Erratum.
        most recent date the erratum was updated


        :param updated: The updated of this Erratum.
        :type: str
        """
        self._updated = updated

    @property
    def advisory_type(self):
        """
        Gets the advisory_type of this Erratum.
        Type of the erratum.

        Allowed values for this property are: "SECURITY", "BUG", "ENHANCEMENT", "OTHER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The advisory_type of this Erratum.
        :rtype: str
        """
        return self._advisory_type

    @advisory_type.setter
    def advisory_type(self, advisory_type):
        """
        Sets the advisory_type of this Erratum.
        Type of the erratum.


        :param advisory_type: The advisory_type of this Erratum.
        :type: str
        """
        allowed_values = ["SECURITY", "BUG", "ENHANCEMENT", "OTHER"]
        if not value_allowed_none_or_none_sentinel(advisory_type, allowed_values):
            advisory_type = 'UNKNOWN_ENUM_VALUE'
        self._advisory_type = advisory_type

    @property
    def _from(self):
        """
        Gets the _from of this Erratum.
        Information specifying from where the erratum was release.


        :return: The _from of this Erratum.
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """
        Sets the _from of this Erratum.
        Information specifying from where the erratum was release.


        :param _from: The _from of this Erratum.
        :type: str
        """
        self.__from = _from

    @property
    def solution(self):
        """
        Gets the solution of this Erratum.
        Information describing how the erratum can be resolved.


        :return: The solution of this Erratum.
        :rtype: str
        """
        return self._solution

    @solution.setter
    def solution(self, solution):
        """
        Sets the solution of this Erratum.
        Information describing how the erratum can be resolved.


        :param solution: The solution of this Erratum.
        :type: str
        """
        self._solution = solution

    @property
    def references(self):
        """
        Gets the references of this Erratum.
        Information describing how to find more information about the erratum.


        :return: The references of this Erratum.
        :rtype: str
        """
        return self._references

    @references.setter
    def references(self, references):
        """
        Sets the references of this Erratum.
        Information describing how to find more information about the erratum.


        :param references: The references of this Erratum.
        :type: str
        """
        self._references = references

    @property
    def affected_instances(self):
        """
        Gets the affected_instances of this Erratum.
        list of managed instances  to this erratum


        :return: The affected_instances of this Erratum.
        :rtype: list[oci.os_management.models.Id]
        """
        return self._affected_instances

    @affected_instances.setter
    def affected_instances(self, affected_instances):
        """
        Sets the affected_instances of this Erratum.
        list of managed instances  to this erratum


        :param affected_instances: The affected_instances of this Erratum.
        :type: list[oci.os_management.models.Id]
        """
        self._affected_instances = affected_instances

    @property
    def related_cves(self):
        """
        Gets the related_cves of this Erratum.
        list of CVEs applicable to this erratum


        :return: The related_cves of this Erratum.
        :rtype: list[str]
        """
        return self._related_cves

    @related_cves.setter
    def related_cves(self, related_cves):
        """
        Sets the related_cves of this Erratum.
        list of CVEs applicable to this erratum


        :param related_cves: The related_cves of this Erratum.
        :type: list[str]
        """
        self._related_cves = related_cves

    @property
    def software_sources(self):
        """
        Gets the software_sources of this Erratum.
        list of Software Sources


        :return: The software_sources of this Erratum.
        :rtype: list[oci.os_management.models.Id]
        """
        return self._software_sources

    @software_sources.setter
    def software_sources(self, software_sources):
        """
        Sets the software_sources of this Erratum.
        list of Software Sources


        :param software_sources: The software_sources of this Erratum.
        :type: list[oci.os_management.models.Id]
        """
        self._software_sources = software_sources

    @property
    def packages(self):
        """
        Gets the packages of this Erratum.
        list of Packages affected by this erratum


        :return: The packages of this Erratum.
        :rtype: list[oci.os_management.models.SoftwarePackageSummary]
        """
        return self._packages

    @packages.setter
    def packages(self, packages):
        """
        Sets the packages of this Erratum.
        list of Packages affected by this erratum


        :param packages: The packages of this Erratum.
        :type: list[oci.os_management.models.SoftwarePackageSummary]
        """
        self._packages = packages

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RecalledData(object):
    """
    This is the information about recalled data
    """

    #: A constant which can be used with the status property of a RecalledData.
    #: This constant has a value of "RECALLED"
    STATUS_RECALLED = "RECALLED"

    #: A constant which can be used with the status property of a RecalledData.
    #: This constant has a value of "PENDING"
    STATUS_PENDING = "PENDING"

    def __init__(self, **kwargs):
        """
        Initializes a new RecalledData object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_data_ended:
            The value to assign to the time_data_ended property of this RecalledData.
        :type time_data_ended: datetime

        :param time_data_started:
            The value to assign to the time_data_started property of this RecalledData.
        :type time_data_started: datetime

        :param time_started:
            The value to assign to the time_started property of this RecalledData.
        :type time_started: datetime

        :param status:
            The value to assign to the status property of this RecalledData.
            Allowed values for this property are: "RECALLED", "PENDING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param recall_count:
            The value to assign to the recall_count property of this RecalledData.
        :type recall_count: int

        :param storage_usage_in_bytes:
            The value to assign to the storage_usage_in_bytes property of this RecalledData.
        :type storage_usage_in_bytes: int

        """
        self.swagger_types = {
            'time_data_ended': 'datetime',
            'time_data_started': 'datetime',
            'time_started': 'datetime',
            'status': 'str',
            'recall_count': 'int',
            'storage_usage_in_bytes': 'int'
        }

        self.attribute_map = {
            'time_data_ended': 'timeDataEnded',
            'time_data_started': 'timeDataStarted',
            'time_started': 'timeStarted',
            'status': 'status',
            'recall_count': 'recallCount',
            'storage_usage_in_bytes': 'storageUsageInBytes'
        }

        self._time_data_ended = None
        self._time_data_started = None
        self._time_started = None
        self._status = None
        self._recall_count = None
        self._storage_usage_in_bytes = None

    @property
    def time_data_ended(self):
        """
        **[Required]** Gets the time_data_ended of this RecalledData.
        This is the end of the time range of the related data


        :return: The time_data_ended of this RecalledData.
        :rtype: datetime
        """
        return self._time_data_ended

    @time_data_ended.setter
    def time_data_ended(self, time_data_ended):
        """
        Sets the time_data_ended of this RecalledData.
        This is the end of the time range of the related data


        :param time_data_ended: The time_data_ended of this RecalledData.
        :type: datetime
        """
        self._time_data_ended = time_data_ended

    @property
    def time_data_started(self):
        """
        **[Required]** Gets the time_data_started of this RecalledData.
        This is the start of the time range of the related data


        :return: The time_data_started of this RecalledData.
        :rtype: datetime
        """
        return self._time_data_started

    @time_data_started.setter
    def time_data_started(self, time_data_started):
        """
        Sets the time_data_started of this RecalledData.
        This is the start of the time range of the related data


        :param time_data_started: The time_data_started of this RecalledData.
        :type: datetime
        """
        self._time_data_started = time_data_started

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this RecalledData.
        This is the time when the first recall operation was started for this RecalledData


        :return: The time_started of this RecalledData.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this RecalledData.
        This is the time when the first recall operation was started for this RecalledData


        :param time_started: The time_started of this RecalledData.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def status(self):
        """
        **[Required]** Gets the status of this RecalledData.
        This is the status of the recall

        Allowed values for this property are: "RECALLED", "PENDING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this RecalledData.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this RecalledData.
        This is the status of the recall


        :param status: The status of this RecalledData.
        :type: str
        """
        allowed_values = ["RECALLED", "PENDING"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def recall_count(self):
        """
        **[Required]** Gets the recall_count of this RecalledData.
        This is the number of recall operations for this recall.  Note one RecalledData can be merged from the results
        of several recall operations if the time duration of the results of the recall operations overlap.


        :return: The recall_count of this RecalledData.
        :rtype: int
        """
        return self._recall_count

    @recall_count.setter
    def recall_count(self, recall_count):
        """
        Sets the recall_count of this RecalledData.
        This is the number of recall operations for this recall.  Note one RecalledData can be merged from the results
        of several recall operations if the time duration of the results of the recall operations overlap.


        :param recall_count: The recall_count of this RecalledData.
        :type: int
        """
        self._recall_count = recall_count

    @property
    def storage_usage_in_bytes(self):
        """
        **[Required]** Gets the storage_usage_in_bytes of this RecalledData.
        This is the size in bytes


        :return: The storage_usage_in_bytes of this RecalledData.
        :rtype: int
        """
        return self._storage_usage_in_bytes

    @storage_usage_in_bytes.setter
    def storage_usage_in_bytes(self, storage_usage_in_bytes):
        """
        Sets the storage_usage_in_bytes of this RecalledData.
        This is the size in bytes


        :param storage_usage_in_bytes: The storage_usage_in_bytes of this RecalledData.
        :type: int
        """
        self._storage_usage_in_bytes = storage_usage_in_bytes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .wait_criteria_summary import WaitCriteriaSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AbsoluteWaitCriteriaSummary(WaitCriteriaSummary):
    """
    Specifies the absolute wait criteria, user can specify fixed length of wait duration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AbsoluteWaitCriteriaSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.AbsoluteWaitCriteriaSummary.wait_type` attribute
        of this class is ``ABSOLUTE_WAIT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param wait_type:
            The value to assign to the wait_type property of this AbsoluteWaitCriteriaSummary.
            Allowed values for this property are: "ABSOLUTE_WAIT"
        :type wait_type: str

        :param wait_duration:
            The value to assign to the wait_duration property of this AbsoluteWaitCriteriaSummary.
        :type wait_duration: str

        """
        self.swagger_types = {
            'wait_type': 'str',
            'wait_duration': 'str'
        }

        self.attribute_map = {
            'wait_type': 'waitType',
            'wait_duration': 'waitDuration'
        }

        self._wait_type = None
        self._wait_duration = None
        self._wait_type = 'ABSOLUTE_WAIT'

    @property
    def wait_duration(self):
        """
        Gets the wait_duration of this AbsoluteWaitCriteriaSummary.
        The absolute wait duration. Minimum wait duration must be 5 seconds. Maximum wait duration can be up to 2 days.


        :return: The wait_duration of this AbsoluteWaitCriteriaSummary.
        :rtype: str
        """
        return self._wait_duration

    @wait_duration.setter
    def wait_duration(self, wait_duration):
        """
        Sets the wait_duration of this AbsoluteWaitCriteriaSummary.
        The absolute wait duration. Minimum wait duration must be 5 seconds. Maximum wait duration can be up to 2 days.


        :param wait_duration: The wait_duration of this AbsoluteWaitCriteriaSummary.
        :type: str
        """
        self._wait_duration = wait_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .awr_query_result import AwrQueryResult
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrDbSnapshotCollection(AwrQueryResult):
    """
    The list of AWR snapshots for one database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrDbSnapshotCollection object with values from keyword arguments. The default value of the :py:attr:`~oci.database_management.models.AwrDbSnapshotCollection.awr_result_type` attribute
        of this class is ``AWRDB_SNAPSHOT_SET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AwrDbSnapshotCollection.
        :type name: str

        :param version:
            The value to assign to the version property of this AwrDbSnapshotCollection.
        :type version: str

        :param query_key:
            The value to assign to the query_key property of this AwrDbSnapshotCollection.
        :type query_key: str

        :param db_query_time_in_secs:
            The value to assign to the db_query_time_in_secs property of this AwrDbSnapshotCollection.
        :type db_query_time_in_secs: float

        :param awr_result_type:
            The value to assign to the awr_result_type property of this AwrDbSnapshotCollection.
            Allowed values for this property are: "AWRDB_SET", "AWRDB_SNAPSHOT_RANGE_SET", "AWRDB_SNAPSHOT_SET", "AWRDB_METRICS_SET", "AWRDB_SYSSTAT_SET", "AWRDB_TOP_EVENT_SET", "AWRDB_EVENT_SET", "AWRDB_EVENT_HISTOGRAM", "AWRDB_DB_PARAMETER_SET", "AWRDB_DB_PARAMETER_CHANGE", "AWRDB_ASH_CPU_USAGE_SET", "AWRDB_DB_REPORT", "AWRDB_SQL_REPORT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type awr_result_type: str

        :param items:
            The value to assign to the items property of this AwrDbSnapshotCollection.
        :type items: list[oci.database_management.models.AwrDbSnapshotSummary]

        """
        self.swagger_types = {
            'name': 'str',
            'version': 'str',
            'query_key': 'str',
            'db_query_time_in_secs': 'float',
            'awr_result_type': 'str',
            'items': 'list[AwrDbSnapshotSummary]'
        }

        self.attribute_map = {
            'name': 'name',
            'version': 'version',
            'query_key': 'queryKey',
            'db_query_time_in_secs': 'dbQueryTimeInSecs',
            'awr_result_type': 'awrResultType',
            'items': 'items'
        }

        self._name = None
        self._version = None
        self._query_key = None
        self._db_query_time_in_secs = None
        self._awr_result_type = None
        self._items = None
        self._awr_result_type = 'AWRDB_SNAPSHOT_SET'

    @property
    def items(self):
        """
        Gets the items of this AwrDbSnapshotCollection.
        A list of AWR snapshot summary data.


        :return: The items of this AwrDbSnapshotCollection.
        :rtype: list[oci.database_management.models.AwrDbSnapshotSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this AwrDbSnapshotCollection.
        A list of AWR snapshot summary data.


        :param items: The items of this AwrDbSnapshotCollection.
        :type: list[oci.database_management.models.AwrDbSnapshotSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .application_usage import ApplicationUsage
from .application_usage_collection import ApplicationUsageCollection
from .change_fleet_compartment_details import ChangeFleetCompartmentDetails
from .create_fleet_details import CreateFleetDetails
from .fleet import Fleet
from .fleet_agent_configuration import FleetAgentConfiguration
from .fleet_agent_os_configuration import FleetAgentOsConfiguration
from .fleet_collection import FleetCollection
from .fleet_summary import FleetSummary
from .installation_usage import InstallationUsage
from .installation_usage_collection import InstallationUsageCollection
from .jre_usage import JreUsage
from .jre_usage_collection import JreUsageCollection
from .managed_instance_usage import ManagedInstanceUsage
from .managed_instance_usage_collection import ManagedInstanceUsageCollection
from .operating_system import OperatingSystem
from .update_fleet_agent_configuration_details import UpdateFleetAgentConfigurationDetails
from .update_fleet_details import UpdateFleetDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource

# Maps type names to classes for jms services.
jms_type_mapping = {
    "ApplicationUsage": ApplicationUsage,
    "ApplicationUsageCollection": ApplicationUsageCollection,
    "ChangeFleetCompartmentDetails": ChangeFleetCompartmentDetails,
    "CreateFleetDetails": CreateFleetDetails,
    "Fleet": Fleet,
    "FleetAgentConfiguration": FleetAgentConfiguration,
    "FleetAgentOsConfiguration": FleetAgentOsConfiguration,
    "FleetCollection": FleetCollection,
    "FleetSummary": FleetSummary,
    "InstallationUsage": InstallationUsage,
    "InstallationUsageCollection": InstallationUsageCollection,
    "JreUsage": JreUsage,
    "JreUsageCollection": JreUsageCollection,
    "ManagedInstanceUsage": ManagedInstanceUsage,
    "ManagedInstanceUsageCollection": ManagedInstanceUsageCollection,
    "OperatingSystem": OperatingSystem,
    "UpdateFleetAgentConfigurationDetails": UpdateFleetAgentConfigurationDetails,
    "UpdateFleetDetails": UpdateFleetDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateContainerRepositoryDetails(object):
    """
    Update container repository request details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateContainerRepositoryDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_immutable:
            The value to assign to the is_immutable property of this UpdateContainerRepositoryDetails.
        :type is_immutable: bool

        :param is_public:
            The value to assign to the is_public property of this UpdateContainerRepositoryDetails.
        :type is_public: bool

        :param readme:
            The value to assign to the readme property of this UpdateContainerRepositoryDetails.
        :type readme: oci.artifacts.models.ContainerRepositoryReadme

        """
        self.swagger_types = {
            'is_immutable': 'bool',
            'is_public': 'bool',
            'readme': 'ContainerRepositoryReadme'
        }

        self.attribute_map = {
            'is_immutable': 'isImmutable',
            'is_public': 'isPublic',
            'readme': 'readme'
        }

        self._is_immutable = None
        self._is_public = None
        self._readme = None

    @property
    def is_immutable(self):
        """
        Gets the is_immutable of this UpdateContainerRepositoryDetails.
        Whether the repository is immutable. Images cannot be overwritten in an immutable repository.


        :return: The is_immutable of this UpdateContainerRepositoryDetails.
        :rtype: bool
        """
        return self._is_immutable

    @is_immutable.setter
    def is_immutable(self, is_immutable):
        """
        Sets the is_immutable of this UpdateContainerRepositoryDetails.
        Whether the repository is immutable. Images cannot be overwritten in an immutable repository.


        :param is_immutable: The is_immutable of this UpdateContainerRepositoryDetails.
        :type: bool
        """
        self._is_immutable = is_immutable

    @property
    def is_public(self):
        """
        Gets the is_public of this UpdateContainerRepositoryDetails.
        Whether the repository is public. A public repository allows unauthenticated access.


        :return: The is_public of this UpdateContainerRepositoryDetails.
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """
        Sets the is_public of this UpdateContainerRepositoryDetails.
        Whether the repository is public. A public repository allows unauthenticated access.


        :param is_public: The is_public of this UpdateContainerRepositoryDetails.
        :type: bool
        """
        self._is_public = is_public

    @property
    def readme(self):
        """
        Gets the readme of this UpdateContainerRepositoryDetails.

        :return: The readme of this UpdateContainerRepositoryDetails.
        :rtype: oci.artifacts.models.ContainerRepositoryReadme
        """
        return self._readme

    @readme.setter
    def readme(self, readme):
        """
        Sets the readme of this UpdateContainerRepositoryDetails.

        :param readme: The readme of this UpdateContainerRepositoryDetails.
        :type: oci.artifacts.models.ContainerRepositoryReadme
        """
        self._readme = readme

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseHomeMetrics(object):
    """
    The response containing the metric collection for a specific database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseHomeMetrics object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_home_metrics:
            The value to assign to the database_home_metrics property of this DatabaseHomeMetrics.
        :type database_home_metrics: oci.database_management.models.DatabaseHomeMetricDefinition

        :param database_instance_home_metrics:
            The value to assign to the database_instance_home_metrics property of this DatabaseHomeMetrics.
        :type database_instance_home_metrics: list[oci.database_management.models.DatabaseInstanceHomeMetricsDefinition]

        """
        self.swagger_types = {
            'database_home_metrics': 'DatabaseHomeMetricDefinition',
            'database_instance_home_metrics': 'list[DatabaseInstanceHomeMetricsDefinition]'
        }

        self.attribute_map = {
            'database_home_metrics': 'databaseHomeMetrics',
            'database_instance_home_metrics': 'databaseInstanceHomeMetrics'
        }

        self._database_home_metrics = None
        self._database_instance_home_metrics = None

    @property
    def database_home_metrics(self):
        """
        **[Required]** Gets the database_home_metrics of this DatabaseHomeMetrics.

        :return: The database_home_metrics of this DatabaseHomeMetrics.
        :rtype: oci.database_management.models.DatabaseHomeMetricDefinition
        """
        return self._database_home_metrics

    @database_home_metrics.setter
    def database_home_metrics(self, database_home_metrics):
        """
        Sets the database_home_metrics of this DatabaseHomeMetrics.

        :param database_home_metrics: The database_home_metrics of this DatabaseHomeMetrics.
        :type: oci.database_management.models.DatabaseHomeMetricDefinition
        """
        self._database_home_metrics = database_home_metrics

    @property
    def database_instance_home_metrics(self):
        """
        Gets the database_instance_home_metrics of this DatabaseHomeMetrics.
        The metrics for the RAC database instances.


        :return: The database_instance_home_metrics of this DatabaseHomeMetrics.
        :rtype: list[oci.database_management.models.DatabaseInstanceHomeMetricsDefinition]
        """
        return self._database_instance_home_metrics

    @database_instance_home_metrics.setter
    def database_instance_home_metrics(self, database_instance_home_metrics):
        """
        Sets the database_instance_home_metrics of this DatabaseHomeMetrics.
        The metrics for the RAC database instances.


        :param database_instance_home_metrics: The database_instance_home_metrics of this DatabaseHomeMetrics.
        :type: list[oci.database_management.models.DatabaseInstanceHomeMetricsDefinition]
        """
        self._database_instance_home_metrics = database_instance_home_metrics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateMountTargetDetails(object):
    """
    Details for creating the mount target.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateMountTargetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this CreateMountTargetDetails.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateMountTargetDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateMountTargetDetails.
        :type display_name: str

        :param hostname_label:
            The value to assign to the hostname_label property of this CreateMountTargetDetails.
        :type hostname_label: str

        :param ip_address:
            The value to assign to the ip_address property of this CreateMountTargetDetails.
        :type ip_address: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateMountTargetDetails.
        :type subnet_id: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateMountTargetDetails.
        :type nsg_ids: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateMountTargetDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateMountTargetDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'hostname_label': 'str',
            'ip_address': 'str',
            'subnet_id': 'str',
            'nsg_ids': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'hostname_label': 'hostnameLabel',
            'ip_address': 'ipAddress',
            'subnet_id': 'subnetId',
            'nsg_ids': 'nsgIds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._display_name = None
        self._hostname_label = None
        self._ip_address = None
        self._subnet_id = None
        self._nsg_ids = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this CreateMountTargetDetails.
        The availability domain in which to create the mount target.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this CreateMountTargetDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CreateMountTargetDetails.
        The availability domain in which to create the mount target.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this CreateMountTargetDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateMountTargetDetails.
        The `OCID`__ of the compartment in which to create the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateMountTargetDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateMountTargetDetails.
        The `OCID`__ of the compartment in which to create the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateMountTargetDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateMountTargetDetails.
        A user-friendly name. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.

        Example: `My mount target`


        :return: The display_name of this CreateMountTargetDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateMountTargetDetails.
        A user-friendly name. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.

        Example: `My mount target`


        :param display_name: The display_name of this CreateMountTargetDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def hostname_label(self):
        """
        Gets the hostname_label of this CreateMountTargetDetails.
        The hostname for the mount target's IP address, used for
        DNS resolution. The value is the hostname portion of the private IP
        address's fully qualified domain name (FQDN). For example,
        `files-1` in the FQDN `files-1.subnet123.vcn1.oraclevcn.com`.
        Must be unique across all VNICs in the subnet and comply
        with `RFC 952`__
        and `RFC 1123`__.

        For more information, see
        `DNS in Your Virtual Cloud Network`__.

        Example: `files-1`

        __ https://tools.ietf.org/html/rfc952
        __ https://tools.ietf.org/html/rfc1123
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/dns.htm


        :return: The hostname_label of this CreateMountTargetDetails.
        :rtype: str
        """
        return self._hostname_label

    @hostname_label.setter
    def hostname_label(self, hostname_label):
        """
        Sets the hostname_label of this CreateMountTargetDetails.
        The hostname for the mount target's IP address, used for
        DNS resolution. The value is the hostname portion of the private IP
        address's fully qualified domain name (FQDN). For example,
        `files-1` in the FQDN `files-1.subnet123.vcn1.oraclevcn.com`.
        Must be unique across all VNICs in the subnet and comply
        with `RFC 952`__
        and `RFC 1123`__.

        For more information, see
        `DNS in Your Virtual Cloud Network`__.

        Example: `files-1`

        __ https://tools.ietf.org/html/rfc952
        __ https://tools.ietf.org/html/rfc1123
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/dns.htm


        :param hostname_label: The hostname_label of this CreateMountTargetDetails.
        :type: str
        """
        self._hostname_label = hostname_label

    @property
    def ip_address(self):
        """
        Gets the ip_address of this CreateMountTargetDetails.
        A private IP address of your choice. Must be an available IP address within
        the subnet's CIDR. If you don't specify a value, Oracle automatically
        assigns a private IP address from the subnet.

        Example: `10.0.3.3`


        :return: The ip_address of this CreateMountTargetDetails.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this CreateMountTargetDetails.
        A private IP address of your choice. Must be an available IP address within
        the subnet's CIDR. If you don't specify a value, Oracle automatically
        assigns a private IP address from the subnet.

        Example: `10.0.3.3`


        :param ip_address: The ip_address of this CreateMountTargetDetails.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this CreateMountTargetDetails.
        The `OCID`__ of the subnet in which to create the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this CreateMountTargetDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateMountTargetDetails.
        The `OCID`__ of the subnet in which to create the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this CreateMountTargetDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateMountTargetDetails.
        A list of Network Security Group `OCIDs`__ associated with this mount target.
        A maximum of 5 is allowed.
        Setting this to an empty array after the list is created removes the mount target from all NSGs.
        For more information about NSGs, see `Security Rules`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this CreateMountTargetDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateMountTargetDetails.
        A list of Network Security Group `OCIDs`__ associated with this mount target.
        A maximum of 5 is allowed.
        Setting this to an empty array after the list is created removes the mount target from all NSGs.
        For more information about NSGs, see `Security Rules`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this CreateMountTargetDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateMountTargetDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair
         with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateMountTargetDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateMountTargetDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair
         with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateMountTargetDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateMountTargetDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateMountTargetDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateMountTargetDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateMountTargetDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ListenerRuleSummary(object):
    """
    The attributes of a rule associated with the specified listener, and the name of the rule set that the rule
    belongs to.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ListenerRuleSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rule:
            The value to assign to the rule property of this ListenerRuleSummary.
        :type rule: oci.load_balancer.models.Rule

        :param rule_set_name:
            The value to assign to the rule_set_name property of this ListenerRuleSummary.
        :type rule_set_name: str

        """
        self.swagger_types = {
            'rule': 'Rule',
            'rule_set_name': 'str'
        }

        self.attribute_map = {
            'rule': 'rule',
            'rule_set_name': 'ruleSetName'
        }

        self._rule = None
        self._rule_set_name = None

    @property
    def rule(self):
        """
        Gets the rule of this ListenerRuleSummary.
        A rule object that applies to the listener.


        :return: The rule of this ListenerRuleSummary.
        :rtype: oci.load_balancer.models.Rule
        """
        return self._rule

    @rule.setter
    def rule(self, rule):
        """
        Sets the rule of this ListenerRuleSummary.
        A rule object that applies to the listener.


        :param rule: The rule of this ListenerRuleSummary.
        :type: oci.load_balancer.models.Rule
        """
        self._rule = rule

    @property
    def rule_set_name(self):
        """
        Gets the rule_set_name of this ListenerRuleSummary.
        The name of the rule set that the rule belongs to.


        :return: The rule_set_name of this ListenerRuleSummary.
        :rtype: str
        """
        return self._rule_set_name

    @rule_set_name.setter
    def rule_set_name(self, rule_set_name):
        """
        Sets the rule_set_name of this ListenerRuleSummary.
        The name of the rule set that the rule belongs to.


        :param rule_set_name: The rule_set_name of this ListenerRuleSummary.
        :type: str
        """
        self._rule_set_name = rule_set_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VolumeSourceDetails(object):
    """
    Specifies the volume source details for a new Block volume. The volume source is either another Block volume in the same Availability Domain or a Block volume backup.
    This is an optional field. If not specified or set to null, the new Block volume will be empty.
    When specified, the new Block volume will contain data from the source volume or backup.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VolumeSourceDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.core.models.VolumeSourceFromBlockVolumeReplicaDetails`
        * :class:`~oci.core.models.VolumeSourceFromVolumeDetails`
        * :class:`~oci.core.models.VolumeSourceFromVolumeBackupDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this VolumeSourceDetails.
        :type type: str

        """
        self.swagger_types = {
            'type': 'str'
        }

        self.attribute_map = {
            'type': 'type'
        }

        self._type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'blockVolumeReplica':
            return 'VolumeSourceFromBlockVolumeReplicaDetails'

        if type == 'volume':
            return 'VolumeSourceFromVolumeDetails'

        if type == 'volumeBackup':
            return 'VolumeSourceFromVolumeBackupDetails'
        else:
            return 'VolumeSourceDetails'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this VolumeSourceDetails.

        :return: The type of this VolumeSourceDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this VolumeSourceDetails.

        :param type: The type of this VolumeSourceDetails.
        :type: str
        """
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Target(object):
    """
    Description of Target.
    """

    #: A constant which can be used with the target_resource_type property of a Target.
    #: This constant has a value of "COMPARTMENT"
    TARGET_RESOURCE_TYPE_COMPARTMENT = "COMPARTMENT"

    #: A constant which can be used with the target_resource_type property of a Target.
    #: This constant has a value of "ERPCLOUD"
    TARGET_RESOURCE_TYPE_ERPCLOUD = "ERPCLOUD"

    #: A constant which can be used with the target_resource_type property of a Target.
    #: This constant has a value of "HCMCLOUD"
    TARGET_RESOURCE_TYPE_HCMCLOUD = "HCMCLOUD"

    #: A constant which can be used with the lifecycle_state property of a Target.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Target.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Target.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Target.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Target.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Target.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Target.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Target object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Target.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this Target.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Target.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this Target.
        :type description: str

        :param target_resource_type:
            The value to assign to the target_resource_type property of this Target.
            Allowed values for this property are: "COMPARTMENT", "ERPCLOUD", "HCMCLOUD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type target_resource_type: str

        :param target_resource_id:
            The value to assign to the target_resource_id property of this Target.
        :type target_resource_id: str

        :param recipe_count:
            The value to assign to the recipe_count property of this Target.
        :type recipe_count: int

        :param target_detector_recipes:
            The value to assign to the target_detector_recipes property of this Target.
        :type target_detector_recipes: list[oci.cloud_guard.models.TargetDetectorRecipe]

        :param target_responder_recipes:
            The value to assign to the target_responder_recipes property of this Target.
        :type target_responder_recipes: list[oci.cloud_guard.models.TargetResponderRecipe]

        :param inherited_by_compartments:
            The value to assign to the inherited_by_compartments property of this Target.
        :type inherited_by_compartments: list[str]

        :param time_created:
            The value to assign to the time_created property of this Target.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Target.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Target.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecyle_details:
            The value to assign to the lifecyle_details property of this Target.
        :type lifecyle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Target.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Target.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Target.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'target_resource_type': 'str',
            'target_resource_id': 'str',
            'recipe_count': 'int',
            'target_detector_recipes': 'list[TargetDetectorRecipe]',
            'target_responder_recipes': 'list[TargetResponderRecipe]',
            'inherited_by_compartments': 'list[str]',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecyle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'target_resource_type': 'targetResourceType',
            'target_resource_id': 'targetResourceId',
            'recipe_count': 'recipeCount',
            'target_detector_recipes': 'targetDetectorRecipes',
            'target_responder_recipes': 'targetResponderRecipes',
            'inherited_by_compartments': 'inheritedByCompartments',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecyle_details': 'lifecyleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._description = None
        self._target_resource_type = None
        self._target_resource_id = None
        self._recipe_count = None
        self._target_detector_recipes = None
        self._target_responder_recipes = None
        self._inherited_by_compartments = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecyle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Target.
        Unique identifier that is immutable on creation


        :return: The id of this Target.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Target.
        Unique identifier that is immutable on creation


        :param id: The id of this Target.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this Target.
        Target Identifier, can be renamed


        :return: The display_name of this Target.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Target.
        Target Identifier, can be renamed


        :param display_name: The display_name of this Target.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Target.
        Compartment Identifier where the resource is created


        :return: The compartment_id of this Target.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Target.
        Compartment Identifier where the resource is created


        :param compartment_id: The compartment_id of this Target.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this Target.
        The target description.


        :return: The description of this Target.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Target.
        The target description.


        :param description: The description of this Target.
        :type: str
        """
        self._description = description

    @property
    def target_resource_type(self):
        """
        **[Required]** Gets the target_resource_type of this Target.
        possible type of targets

        Allowed values for this property are: "COMPARTMENT", "ERPCLOUD", "HCMCLOUD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The target_resource_type of this Target.
        :rtype: str
        """
        return self._target_resource_type

    @target_resource_type.setter
    def target_resource_type(self, target_resource_type):
        """
        Sets the target_resource_type of this Target.
        possible type of targets


        :param target_resource_type: The target_resource_type of this Target.
        :type: str
        """
        allowed_values = ["COMPARTMENT", "ERPCLOUD", "HCMCLOUD"]
        if not value_allowed_none_or_none_sentinel(target_resource_type, allowed_values):
            target_resource_type = 'UNKNOWN_ENUM_VALUE'
        self._target_resource_type = target_resource_type

    @property
    def target_resource_id(self):
        """
        **[Required]** Gets the target_resource_id of this Target.
        Resource ID which the target uses to monitor


        :return: The target_resource_id of this Target.
        :rtype: str
        """
        return self._target_resource_id

    @target_resource_id.setter
    def target_resource_id(self, target_resource_id):
        """
        Sets the target_resource_id of this Target.
        Resource ID which the target uses to monitor


        :param target_resource_id: The target_resource_id of this Target.
        :type: str
        """
        self._target_resource_id = target_resource_id

    @property
    def recipe_count(self):
        """
        **[Required]** Gets the recipe_count of this Target.
        Total number of recipes attached to target


        :return: The recipe_count of this Target.
        :rtype: int
        """
        return self._recipe_count

    @recipe_count.setter
    def recipe_count(self, recipe_count):
        """
        Sets the recipe_count of this Target.
        Total number of recipes attached to target


        :param recipe_count: The recipe_count of this Target.
        :type: int
        """
        self._recipe_count = recipe_count

    @property
    def target_detector_recipes(self):
        """
        Gets the target_detector_recipes of this Target.
        List of detector recipes associated with target


        :return: The target_detector_recipes of this Target.
        :rtype: list[oci.cloud_guard.models.TargetDetectorRecipe]
        """
        return self._target_detector_recipes

    @target_detector_recipes.setter
    def target_detector_recipes(self, target_detector_recipes):
        """
        Sets the target_detector_recipes of this Target.
        List of detector recipes associated with target


        :param target_detector_recipes: The target_detector_recipes of this Target.
        :type: list[oci.cloud_guard.models.TargetDetectorRecipe]
        """
        self._target_detector_recipes = target_detector_recipes

    @property
    def target_responder_recipes(self):
        """
        Gets the target_responder_recipes of this Target.
        List of responder recipes associated with target


        :return: The target_responder_recipes of this Target.
        :rtype: list[oci.cloud_guard.models.TargetResponderRecipe]
        """
        return self._target_responder_recipes

    @target_responder_recipes.setter
    def target_responder_recipes(self, target_responder_recipes):
        """
        Sets the target_responder_recipes of this Target.
        List of responder recipes associated with target


        :param target_responder_recipes: The target_responder_recipes of this Target.
        :type: list[oci.cloud_guard.models.TargetResponderRecipe]
        """
        self._target_responder_recipes = target_responder_recipes

    @property
    def inherited_by_compartments(self):
        """
        Gets the inherited_by_compartments of this Target.
        List of inherited compartments


        :return: The inherited_by_compartments of this Target.
        :rtype: list[str]
        """
        return self._inherited_by_compartments

    @inherited_by_compartments.setter
    def inherited_by_compartments(self, inherited_by_compartments):
        """
        Sets the inherited_by_compartments of this Target.
        List of inherited compartments


        :param inherited_by_compartments: The inherited_by_compartments of this Target.
        :type: list[str]
        """
        self._inherited_by_compartments = inherited_by_compartments

    @property
    def time_created(self):
        """
        Gets the time_created of this Target.
        The date and time the target was created. Format defined by RFC3339.


        :return: The time_created of this Target.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Target.
        The date and time the target was created. Format defined by RFC3339.


        :param time_created: The time_created of this Target.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Target.
        The date and time the target was updated. Format defined by RFC3339.


        :return: The time_updated of this Target.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Target.
        The date and time the target was updated. Format defined by RFC3339.


        :param time_updated: The time_updated of this Target.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Target.
        The current state of the Target.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Target.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Target.
        The current state of the Target.


        :param lifecycle_state: The lifecycle_state of this Target.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecyle_details(self):
        """
        Gets the lifecyle_details of this Target.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecyle_details of this Target.
        :rtype: str
        """
        return self._lifecyle_details

    @lifecyle_details.setter
    def lifecyle_details(self, lifecyle_details):
        """
        Sets the lifecyle_details of this Target.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecyle_details: The lifecyle_details of this Target.
        :type: str
        """
        self._lifecyle_details = lifecyle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Target.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Target.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Target.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Target.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Target.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Target.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Target.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Target.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Target.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        System tags can be viewed by users, but can only be created by the system.

        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this Target.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Target.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        System tags can be viewed by users, but can only be created by the system.

        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this Target.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
